@@ -1,8 +1,7 @@
-from neuro_helper.abstract.map import Space
-
-
 __all__ = ["task_order"]
 
+from neuro_helper.abstract import Space
+
 
 def task_order(space: Space, with_rest=True):
     if space in [Space.K59, Space.K59_CORTEX]:
