@@ -1,13 +1,12 @@
+__all__ = ["MEGLocalStorage", "MEGRCloneStorage", "load_raw_file"]
+
 import re
 from scipy.io import loadmat
 import numpy as np
-from neuro_helper.abstract.map import TemplateName
+from neuro_helper.abstract import TemplateName
 from neuro_helper.storage import LocalStorage, StorageFile, ANYTHING, RCloneStorage
 
 
-__all__ = ["MEGLocalStorage", "MEGRCloneStorage", "load_raw_file"]
-
-
 class MEGLocalStorage(LocalStorage):
     def __init__(self, root: str, tpt_name: TemplateName, task_name: str, scan_id: str):
         if task_name == "Rest":
